@@ -3,12 +3,12 @@
 import asyncio
 import logging
 from collections.abc import Generator
-from contextlib import suppress
 from http import HTTPStatus
 from typing import Any, Final, Self, cast
 
 from aiohttp import ClientSession
 from dacite import from_dict
+from yarl import URL
 
 from .const import (
     ATTR_AQI,
@@ -101,11 +101,14 @@ class Gios:
             msg = "Invalid measuring station data from GIOS API"
             raise InvalidSensorsDataError(msg)
 
-        for sensor_dict in self._station_data:
-            data[sensor_dict["param"]["paramCode"].lower()] = {
-                ATTR_ID: sensor_dict[ATTR_ID],
-                ATTR_NAME: POLLUTANT_MAP[sensor_dict["param"]["paramName"]],
+        data = {
+            sensor["Wskaźnik - wzór"].lower(): {
+                ATTR_ID: sensor["Identyfikator stanowiska"],
+                ATTR_NAME: POLLUTANT_MAP[sensor["Wskaźnik"]],
             }
+            for sensor in self._station_data
+            if sensor["Wskaźnik"] in POLLUTANT_MAP
+        }
 
         sensors = await self._get_all_sensors(data)
 
@@ -114,18 +117,19 @@ class Gios:
         # we take the earlier value.
         for sensor, sensor_data in data.items():
             try:
-                if sensors[sensor]["values"][0][ATTR_VALUE]:
-                    sensor_data[ATTR_VALUE] = sensors[sensor]["values"][0][ATTR_VALUE]
-                elif sensors[sensor].get("values")[1][ATTR_VALUE]:
-                    sensor_data[ATTR_VALUE] = sensors[sensor]["values"][1][ATTR_VALUE]
+                sensor_entry = sensors[sensor]["Lista danych pomiarowych"]
+                if (
+                    sensor_value := sensor_entry[0]["Wartość"]
+                    or sensor_entry[1]["Wartość"]
+                ):
+                    sensor_data[ATTR_VALUE] = sensor_value
                 else:
                     invalid_sensors.append(sensor)
             except (IndexError, KeyError, TypeError):
                 invalid_sensors.append(sensor)
 
-        if invalid_sensors:
-            for sensor in invalid_sensors:
-                data.pop(sensor)
+        for sensor in invalid_sensors:
+            data.pop(sensor)
 
         if not data:
             msg = "Invalid sensor data from GIOS API"
@@ -134,18 +138,16 @@ class Gios:
         indexes = await self._get_indexes()
 
         for sensor, sensor_data in data.items():
-            with suppress(IndexError, KeyError, TypeError):
-                index_level = ATTR_INDEX_LEVEL.format(sensor.lower().replace(".", ""))
-                sensor_data[ATTR_INDEX] = STATE_MAP[
-                    indexes[index_level]["indexLevelName"]
-                ]
+            if index_value := indexes.get("AqIndex", {}).get(
+                ATTR_INDEX_LEVEL.format(sensor.upper())
+            ):
+                sensor_data[ATTR_INDEX] = STATE_MAP[index_value]
 
-        with suppress(IndexError, KeyError, TypeError):
-            if indexes["stIndexLevel"]["indexLevelName"]:
-                data[ATTR_AQI.lower()] = {ATTR_NAME: ATTR_AQI}
-                data[ATTR_AQI.lower()][ATTR_VALUE] = STATE_MAP[
-                    indexes["stIndexLevel"]["indexLevelName"]
-                ]
+        if index_value := indexes.get("AqIndex", {}).get("Nazwa kategorii indeksu"):
+            data[ATTR_AQI.lower()] = {
+                ATTR_NAME: ATTR_AQI,
+                ATTR_VALUE: STATE_MAP[index_value],
+            }
 
         if data.get("pm2.5"):
             data["pm25"] = data.pop("pm2.5")
@@ -155,22 +157,24 @@ class Gios:
 
     async def _get_stations(self) -> Any:
         """Retrieve list of measurement stations."""
-        return await self._async_get(URL_STATIONS)
+        result = await self._async_get(URL_STATIONS.with_query(page=0, size=1000))
+        return result.get("Lista stacji pomiarowych", [])
 
     def _parse_stations(self, stations: list[dict[str, Any]]) -> Generator[GiosStation]:
         """Parse stations data."""
         for station in stations:
             yield GiosStation(
-                cast(int, station["id"]),
-                station["stationName"],
-                float(station["gegrLat"]),
-                float(station["gegrLon"]),
+                cast(int, station["Identyfikator stacji"]),
+                station["Nazwa stacji"],
+                float(station["WGS84 φ N"]),
+                float(station["WGS84 λ E"]),
             )
 
     async def _get_station(self) -> Any:
         """Retrieve measuring station data."""
-        url = URL_STATION.format(self.station_id)
-        return await self._async_get(url)
+        url = URL_STATION / str(self.station_id)
+        result = await self._async_get(url)
+        return result.get("Lista stanowisk pomiarowych dla podanej stacji", [])
 
     async def _get_all_sensors(self, sensors: dict[str, Any]) -> dict[str, Any]:
         """Retrieve all sensors data."""
@@ -180,20 +184,26 @@ class Gios:
 
     async def _get_sensor(self, sensor: int) -> Any:
         """Retrieve sensor data."""
-        url = URL_SENSOR.format(sensor)
-        return await self._async_get(url)
+        url = URL_SENSOR / str(sensor)
+        return await self._async_get(url, do_not_raise=True)
 
     async def _get_indexes(self) -> Any:
         """Retrieve indexes data."""
-        url = URL_INDEXES.format(self.station_id)
+        url = URL_INDEXES / str(self.station_id)
         return await self._async_get(url)
 
-    async def _async_get(self, url: str) -> Any:
+    async def _async_get(self, url: URL, do_not_raise: bool = False) -> Any:
         """Retrieve data from GIOS API."""
         async with self.session.get(url) as resp:
             _LOGGER.debug("Data retrieved from %s, status: %s", url, resp.status)
             if resp.status != HTTPStatus.OK.value:
-                _LOGGER.warning("Invalid response from GIOS API: %s", resp.status)
+                msg = f"Invalid response from GIOS API: {resp.status}"
+
+                if do_not_raise:
+                    _LOGGER.info(msg)
+                    return {}
+
+                _LOGGER.warning(msg)
                 raise ApiError(str(resp.status))
 
             return await resp.json()
